@@ -22,7 +22,7 @@ def test_validation_work_on_wrong_yaml():
     try:
         ValuesYaml.from_dict(values)
     except Exception as e:
-        assert "appCommon.requireHttps" in str(e)
+        assert "common.requireHttps" in str(e)
 
 
 def test_validation():
@@ -41,4 +41,4 @@ def test_validation():
         """])
         assert False
     except Exception as e:
-        assert "appCommon.requireHttps" in str(e)
+        assert "common.requireHttps" in str(e)
